docx_dart library

Classes

BaseStyle
Body
Proxy for <w:body> element in this document.
CharacterStyle
Cm
Convenience class for creating a Length in centimeters.
CoreProperties
Proxy exposing Dublin Core properties stored in /docProps/core.xml.
Document
WordprocessingML (WML) document.
DocxUnit
Helper class for easily generating common Word units.
Emu
Convenience class for creating a Length directly from EMU.
Font
Proxy object for character-level formatting (font) of a Run or Style.
Inches
Convenience class for creating a Length in inches.
InlineParagraphStyle
Defines inline formatting properties applied directly to a Paragraph.
InlineRunStyle
Defines inline formatting properties applied directly to a Run.
InlineShape
Proxy for a <wp:inline> element representing an inline shape.
InlineShapes
Sequence of inline shapes contained in a document body.
Length
Base class for length units like Inches, Cm, Mm, Pt, and Emu.
Mm
Convenience class for creating a Length in millimeters.
Paragraph
Proxy object wrapping a <w:p> element.
ParagraphFormat
Provides access to paragraph-level formatting options.
ParagraphStyle
Pt
Convenience class for creating a Length in points (1/72 inch).
RGBColor
Immutable value object defining a particular RGB color.
Run
Proxy object wrapping a <w:r> element.
Section
Document section, providing access to section and page setup settings. Also provides access to headers and footers.
Sections
Sequence of Section objects corresponding to the sections in the document.
Settings
Table
Twips
Convenience class for creating a Length in twips (1/20 point).

Enums

ParagraphAlignment
Simplified paragraph alignment for InlineParagraphStyle.
Underline
Simplified underline styles for InlineRunStyle.
WD_BUILTIN_STYLE
Specifies a built-in Microsoft Word style.
WD_COLOR_INDEX
Specifies a standard preset color to apply.
WD_LINE_SPACING
Specifies a line spacing format to be applied to a paragraph.
WD_ORIENTATION
Specifies the page layout orientation.
WD_PARAGRAPH_ALIGNMENT
Specifies paragraph justification type.
WD_SECTION_START
Specifies the start type of a section break.
WD_STYLE_TYPE
Specifies one of the four style types: paragraph, character, list, or table.
WD_UNDERLINE
Specifies the style of underline applied to a run of characters.

Extensions

ParagraphAlignmentMapper on ParagraphAlignment
Helper to map the simplified enums back to docx_dart's internal enums.
UnderlineMapper on Underline

Functions

loadDocxDocument([dynamic docxSource]) Document
Load a WordprocessingML document from docxSource or the built-in default template when omitted.

Typedefs

WD_ALIGN_PARAGRAPH = WD_PARAGRAPH_ALIGNMENT
Alias for WD_PARAGRAPH_ALIGNMENT.
WD_BREAK = WD_BREAK_TYPE
Alias for WD_BREAK_TYPE.
Alias for WD_HEADER_FOOTER_INDEX.
WD_SECTION = WD_SECTION_START
Alias for WD_SECTION_START.
WD_STYLE = WD_BUILTIN_STYLE
Alias for WD_BUILTIN_STYLE.