Body class

Proxy for <w:body> element in this document.

It's primary role is a container for document content.

Constructors

Body(CT_Body _bodyElement, Document parent)

Properties

hashCode int
The hash code for this object.
no setterinherited
paragraphs List<Paragraph>
Read-only list containing the paragraphs in this container, in document order.
no setterinherited
part → StoryPart
The story part (e.g., DocumentPart, HeaderPart) containing this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tables List<Table>
Read-only list containing the tables in this container, in document order.
no setterinherited

Methods

addParagraph({String text = "", dynamic style}) Paragraph
Return paragraph newly added to the end of the content in this container. text is added in a single run. style may be a style name or a ParagraphStyle instance (or an InlineParagraphStyle to directly apply inline formatting).
inherited
addTable(int rows, int cols, [Length? width]) Table
Return a new Table object appended to the container.
inherited
clear() → void
Removes all block-level content (paragraphs and tables) from this container.
inherited
clearContent() Body
Return this Body instance after clearing it of all content.
iterInnerContent() Iterable
Generate each Paragraph or Table object within this container, in document order.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeParagraph(Paragraph paragraph) → void
Removes the specified paragraph from this container.
inherited
setElementProvider(BlockItemElement elementProvider()) → void
Allows subclasses to update how the backing element is resolved.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited