InlineParagraphStyle class

Defines inline formatting properties applied directly to a Paragraph.

Constructors

InlineParagraphStyle({ParagraphAlignment? alignment, double? spaceBeforePt, double? spaceAfterPt, double? lineSpacing, double? firstLineIndentCm})
const

Properties

alignment ParagraphAlignment?
final
firstLineIndentCm double?
final
hashCode int
The hash code for this object.
no setterinherited
lineSpacing double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceAfterPt double?
final
spaceBeforePt double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited