ParagraphFormat class
Provides access to paragraph-level formatting options.
Constructors
- ParagraphFormat(BaseOxmlElement element)
Properties
- alignment ↔ WD_PARAGRAPH_ALIGNMENT?
-
getter/setter pair
- firstLineIndent ↔ Length?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- keepTogether ↔ bool?
-
getter/setter pair
- keepWithNext ↔ bool?
-
getter/setter pair
- leftIndent ↔ Length?
-
getter/setter pair
- lineSpacing ↔ dynamic
-
getter/setter pair
- lineSpacingRule ↔ WD_LINE_SPACING?
-
getter/setter pair
- pageBreakBefore ↔ bool?
-
getter/setter pair
- part → XmlPart
-
The package part containing this object's element.
Throws StateError if the parent context is not available.
no setterinherited
- rightIndent ↔ Length?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spaceAfter ↔ Length?
-
getter/setter pair
- spaceBefore ↔ Length?
-
getter/setter pair
- tabStops → TabStops
-
no setter
- widowControl ↔ bool?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited