ParagraphStyle class

Inheritance

Constructors

ParagraphStyle(BaseOxmlElement element, [ProvidesXmlPart? parent])

Properties

builtin bool
no setterinherited
font Font
Character-level formatting options (font) for this style.
no setter
hashCode int
The hash code for this object.
no setterinherited
hidden bool
getter/setter pairinherited
locked bool
getter/setter pairinherited
name String?
getter/setter pairinherited
paragraphFormat ParagraphFormat
Paragraph-level formatting options for this style.
no setter
part → XmlPart
The package part containing this object's element. Throws StateError if the parent context is not available.
no setterinherited
priority int?
getter/setter pairinherited
quickStyle bool
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleId String?
getter/setter pairinherited
type WD_STYLE_TYPE
no setterinherited
unhideWhenUsed bool
getter/setter pairinherited

Methods

delete() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited