docx_dart
library
Classes
-
BaseStyle
-
-
Body
-
Proxy for
<w:body> element in this document.
-
CharacterStyle
-
-
Cm
-
Convenience class for creating a Length in centimeters.
-
CoreProperties
-
Proxy exposing Dublin Core properties stored in
/docProps/core.xml.
-
Document
-
WordprocessingML (WML) document.
-
DocxUnit
-
Helper class for easily generating common Word units.
-
Emu
-
Convenience class for creating a Length directly from EMU.
-
Font
-
Proxy object for character-level formatting (font) of a Run or
Style.
-
Inches
-
Convenience class for creating a Length in inches.
-
InlineParagraphStyle
-
Defines inline formatting properties applied directly to a Paragraph.
-
InlineRunStyle
-
Defines inline formatting properties applied directly to a Run.
-
InlineShape
-
Proxy for a
<wp:inline> element representing an inline shape.
-
InlineShapes
-
Sequence of inline shapes contained in a document body.
-
Length
-
Base class for length units like Inches, Cm, Mm, Pt, and Emu.
-
Mm
-
Convenience class for creating a Length in millimeters.
-
Paragraph
-
Proxy object wrapping a
<w:p> element.
-
ParagraphFormat
-
Provides access to paragraph-level formatting options.
-
ParagraphStyle
-
-
Pt
-
Convenience class for creating a Length in points (1/72 inch).
-
RGBColor
-
Immutable value object defining a particular RGB color.
-
Run
-
Proxy object wrapping a
<w:r> element.
-
Section
-
Document section, providing access to section and page setup settings.
Also provides access to headers and footers.
-
Sections
-
Sequence of Section objects corresponding to the sections in the document.
-
Settings
-
-
Table
-
-
Twips
-
Convenience class for creating a Length in twips (1/20 point).
Functions
-
loadDocxDocument([dynamic docxSource])
→ Document
-
Load a WordprocessingML document from
docxSource or the built-in
default template when omitted.