WD_UNDERLINE enum
Specifies the style of underline applied to a run of characters.
MS API name: WdUnderline
URL: http://msdn.microsoft.com/en-us/library/office/ff822388.aspx
Values
- INHERITED → const WD_UNDERLINE
-
Inherit underline setting from containing paragraph.
const WD_UNDERLINE(-1, null, "Inherit underline setting from containing paragraph.") - NONE → const WD_UNDERLINE
-
No underline.
This setting overrides any inherited underline value, so can be used to remove underline from a run that inherits underlining from its containing paragraph. Note this is not the same as assigning
nullto Run.underline.nullis a valid assignment value, but causes the run to inherit its underline value. AssigningWD_UNDERLINE.NONEcauses underlining to be unconditionally turned off.const WD_UNDERLINE(0, "none", "No underline.\n\nThis setting overrides any inherited underline value, so " "can be used to remove underline from a run that inherits underlinin… - SINGLE → const WD_UNDERLINE
-
A single line.
Note that this setting is write-only in the sense that
true(rather thanWD_UNDERLINE.SINGLE) is returned for a run having this setting (in the original python-docx library). In Dart, you would check againstWD_UNDERLINE.SINGLE.const WD_UNDERLINE(1, "single", "A single line.\n\nNote that this setting is write-only in the sense " "that true (rather than `WD_UNDERLINE.SINGLE`) is returned for a run &qu… - WORDS → const WD_UNDERLINE
-
Underline individual words only.
const WD_UNDERLINE(2, "words", "Underline individual words only.") - DOUBLE → const WD_UNDERLINE
-
A double line.
const WD_UNDERLINE(3, "double", "A double line.") - DOTTED → const WD_UNDERLINE
-
Dots.
const WD_UNDERLINE(4, "dotted", "Dots.") - THICK → const WD_UNDERLINE
-
A single thick line.
const WD_UNDERLINE(6, "thick", "A single thick line.") - DASH → const WD_UNDERLINE
-
Dashes.
const WD_UNDERLINE(7, "dash", "Dashes.") - DOT_DASH → const WD_UNDERLINE
-
Alternating dots and dashes.
const WD_UNDERLINE(9, "dotDash", "Alternating dots and dashes.") - DOT_DOT_DASH → const WD_UNDERLINE
-
An alternating dot-dot-dash pattern.
const WD_UNDERLINE(10, "dotDotDash", "An alternating dot-dot-dash pattern.") - WAVY → const WD_UNDERLINE
-
A single wavy line.
const WD_UNDERLINE(11, "wave", "A single wavy line.") - DOTTED_HEAVY → const WD_UNDERLINE
-
Heavy dots.
const WD_UNDERLINE(20, "dottedHeavy", "Heavy dots.") - DASH_HEAVY → const WD_UNDERLINE
-
Heavy dashes.
const WD_UNDERLINE(23, "dashedHeavy", "Heavy dashes.") - DOT_DASH_HEAVY → const WD_UNDERLINE
-
Alternating heavy dots and heavy dashes.
const WD_UNDERLINE(25, "dashDotHeavy", "Alternating heavy dots and heavy dashes.") - DOT_DOT_DASH_HEAVY → const WD_UNDERLINE
-
An alternating heavy dot-dot-dash pattern.
const WD_UNDERLINE(26, "dashDotDotHeavy", "An alternating heavy dot-dot-dash pattern.") - WAVY_HEAVY → const WD_UNDERLINE
-
A heavy wavy line.
const WD_UNDERLINE(27, "wavyHeavy", "A heavy wavy line.") - DASH_LONG → const WD_UNDERLINE
-
Long dashes.
const WD_UNDERLINE(39, "dashLong", "Long dashes.") - WAVY_DOUBLE → const WD_UNDERLINE
-
A double wavy line.
const WD_UNDERLINE(43, "wavyDouble", "A double wavy line.") - DASH_LONG_HEAVY → const WD_UNDERLINE
-
Long heavy dashes.
const WD_UNDERLINE(55, "dashLongHeavy", "Long heavy dashes.")
Properties
- description → String
-
The documentation string for the enum member.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- intValue → int
-
The integer value corresponding to the MS API enum member.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- xmlValue → String?
-
The XML attribute value corresponding to this member (nullable).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromXml(
String? xmlValue) → WD_UNDERLINE -
Returns the enum member corresponding to the XML attribute value
xmlValue. -
toXml(
WD_UNDERLINE? value) → String? -
Returns the XML value for the given enum member
value.
Constants
-
values
→ const List<
WD_UNDERLINE> - A constant List of the values in this enum, in order of their declaration.